Merge branch 'release_0.84.00' into privatestaging

Conflicts:
	include/hcc_detail/hip_runtime.h
	src/hip_hcc.cpp


[ROCm/clr commit: 02e6fc27f4]
This commit is contained in:
Maneesh Gupta
2016-04-22 10:55:58 +05:30
کامیت 03014e8a1d
220فایلهای تغییر یافته به همراه5545 افزوده شده و 11003 حذف شده
@@ -213,7 +213,7 @@ make_test(hipHostAlloc " ")
# BS- comment out since test appears broken - asks for device pointer but pointer was never allocated.
#make_test(hipHostGetFlags " ")
make_test(hipHcc " " )
make_test(hipHostRegister " ")
#make_test(hipHostRegister " ")
make_test(hipStreamL5 " ")
make_test(hipRandomMemcpyAsync " ")
#make_test(hipAPIStreamEnable " ")
@@ -42,9 +42,7 @@ __device__ void double_precision_math_functions()
copysign(1.0, -2.0);
cos(0.0);
cosh(0.0);
#if __hcc_workweek__ >= 16073
cospi(0.0);
#endif
//cyl_bessel_i0(0.0);
//cyl_bessel_i1(0.0);
erf(0.0);
@@ -102,9 +100,7 @@ __device__ void double_precision_math_functions()
//rnorm3d(0.0, 0.0, 1.0);
//rnorm4d(0.0, 0.0, 0.0, 1.0);
round(0.0);
#if __hcc_workweek__ >= 16073
rsqrt(1.0);
#endif
//scalbln(0.0, 1);
scalbn(0.0, 1);
signbit(1.0);
@@ -112,9 +108,7 @@ __device__ void double_precision_math_functions()
//sincos(0.0, &fX, &fY);
//sincospi(0.0, &fX, &fY);
sinh(0.0);
#if __hcc_workweek__ >= 16073
sinpi(0.0);
#endif
sqrt(0.0);
tan(0.0);
tanh(0.0);
@@ -42,9 +42,7 @@ __host__ void double_precision_math_functions()
copysign(1.0, -2.0);
cos(0.0);
cosh(0.0);
#if __hcc_workweek__ >= 16073
cospi(0.0);
#endif
//cyl_bessel_i0(0.0);
//cyl_bessel_i1(0.0);
erf(0.0);
@@ -102,9 +100,7 @@ __host__ void double_precision_math_functions()
//rnorm3d(0.0, 0.0, 1.0);
//rnorm4d(0.0, 0.0, 0.0, 1.0);
round(0.0);
#if __hcc_workweek__ >= 16073
rsqrt(1.0);
#endif
///scalbln(0.0, 1);
scalbn(0.0, 1);
signbit(1.0);
@@ -112,9 +108,7 @@ __host__ void double_precision_math_functions()
sincos(0.0, &fX, &fY);
//sincospi(0.0, &fX, &fY);
sinh(0.0);
#if __hcc_workweek__ >= 16073
sinpi(0.0);
#endif
sqrt(0.0);
tan(0.0);
tanh(0.0);
@@ -42,9 +42,7 @@ __device__ void single_precision_math_functions()
copysignf(1.0f, -2.0f);
cosf(0.0f);
coshf(0.0f);
#if __hcc_workweek__ >= 16073
cospif(0.0f);
#endif
//cyl_bessel_i0f(0.0f);
//cyl_bessel_i1f(0.0f);
erfcf(0.0f);
@@ -103,9 +101,7 @@ __device__ void single_precision_math_functions()
//rnorm4df(0.0f, 0.0f, 0.0f, 1.0f);
//fX = 1.0f; rnormf(1, &fX);
roundf(0.0f);
#if __hcc_workweek__ >= 16073
rsqrtf(1.0f);
#endif
//scalblnf(0.0f, 1);
scalbnf(0.0f, 1);
signbit(1.0f);
@@ -113,9 +109,7 @@ __device__ void single_precision_math_functions()
//sincospif(0.0f, &fX, &fY);
sinf(0.0f);
sinhf(0.0f);
#if __hcc_workweek__ >= 16073
sinpif(0.0f);
#endif
sqrtf(0.0f);
tanf(0.0f);
tanhf(0.0f);
@@ -42,9 +42,7 @@ __host__ void single_precision_math_functions()
copysignf(1.0f, -2.0f);
cosf(0.0f);
coshf(0.0f);
#if __hcc_workweek__ >= 16073
cospif(0.0f);
#endif
//cyl_bessel_i0f(0.0f);
//cyl_bessel_i1f(0.0f);
erfcf(0.0f);
@@ -103,9 +101,7 @@ __host__ void single_precision_math_functions()
//rnorm4df(0.0f, 0.0f, 0.0f, 1.0f);
//fX = 1.0f; rnormf(1, &fX);
roundf(0.0f);
#if __hcc_workweek__ >= 16073
rsqrtf(1.0f);
#endif
///scalblnf(0.0f, 1);
scalbnf(0.0f, 1);
signbit(1.0f);
@@ -113,9 +109,7 @@ __host__ void single_precision_math_functions()
//sincospif(0.0f, &fX, &fY);
sinf(0.0f);
sinhf(0.0f);
#if __hcc_workweek__ >= 16073
sinpif(0.0f);
#endif
sqrtf(0.0f);
tanf(0.0f);
tanhf(0.0f);